@@ -1,7 +1,7 @@
 // drumkv1_config.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -24,14 +24,6 @@
 
 #include "config.h"
 
-#define DRUMKV1_TITLE       PACKAGE_NAME
-
-#define DRUMKV1_SUBTITLE    "an old-school drum-kit sampler."
-#define DRUMKV1_WEBSITE     "https://drumkv1.sourceforge.io"
-#define DRUMKV1_COPYRIGHT   "Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved."
-
-#define DRUMKV1_DOMAIN      "rncbc.org"
-
 
 //-------------------------------------------------------------------------
 // drumkv1_config - Prototype settings class (singleton).
