@@ -1,7 +1,7 @@
 // drumkv1_param.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -293,6 +293,7 @@ void drumkv1_param::loadElements (
 					}
 				}
 			}
+		#if 0//DRUMKV1_LV2_LEGACY_2
 			// Load/correct functional dependent parametrics...
 			const bool bOffset
 				= element->isOffset();
@@ -310,6 +311,7 @@ void drumkv1_param::loadElements (
 			element->setParamValue(drumkv1::GEN1_OFFSET_1, fOffset_1);
 			element->setParamValue(drumkv1::GEN1_OFFSET_2, fOffset_2, 0);
 			element->setParamValue(drumkv1::GEN1_OFFSET_2, fOffset_2);
+		#endif
 		}
 	}
 }
@@ -421,8 +423,11 @@ bool drumkv1_param::loadPreset (
 
 	static QHash<QString, drumkv1::ParamIndex> s_hash;
 	if (s_hash.isEmpty()) {
-		for (uint32_t i = drumkv1::NUM_ELEMENT_PARAMS; i < drumkv1::NUM_PARAMS; ++i) {
+		for (uint32_t i = 0; i < drumkv1::NUM_PARAMS; ++i) {
 			const drumkv1::ParamIndex index = drumkv1::ParamIndex(i);
+			if (index > drumkv1::GEN1_SAMPLE &&
+				index < drumkv1::NUM_ELEMENT_PARAMS)
+				continue;
 			s_hash.insert(drumkv1_param::paramName(index), index);
 		}
 	}
@@ -430,6 +435,8 @@ bool drumkv1_param::loadPreset (
 	const QDir currentDir(QDir::current());
 	QDir::setCurrent(fi.absolutePath());
 
+	int iCurrentElement = -1;
+
 	QDomDocument doc(PROJECT_NAME);
 	if (doc.setContent(&file)) {
 		QDomElement ePreset = doc.documentElement();
@@ -468,6 +475,10 @@ bool drumkv1_param::loadPreset (
 					drumkv1_param::loadElements(pDrumk, eChild);
 				}
 				else
+				if (eChild.tagName() == "current-element") {
+					iCurrentElement = eChild.text().toInt();
+				}
+				else
 				if (eChild.tagName() == "tuning") {
 					drumkv1_param::loadTuning(pDrumk, eChild);
 				}
@@ -480,6 +491,9 @@ bool drumkv1_param::loadPreset (
 	pDrumk->stabilize();
 	pDrumk->reset();
 
+	if (iCurrentElement >= 0)
+		pDrumk->setCurrentElement(iCurrentElement);
+
 	drumkv1_sched::sync_pending();
 
 	pDrumk->running(running);
@@ -512,9 +526,12 @@ bool drumkv1_param::savePreset (
 	ePreset.appendChild(eElements);
 
 	QDomElement eParams = doc.createElement("params");
-	for (uint32_t i = drumkv1::NUM_ELEMENT_PARAMS; i < drumkv1::NUM_PARAMS; ++i) {
-		QDomElement eParam = doc.createElement("param");
+	for (uint32_t i = 0; i < drumkv1::NUM_PARAMS; ++i) {
 		const drumkv1::ParamIndex index = drumkv1::ParamIndex(i);
+		if (index > drumkv1::GEN1_SAMPLE &&
+			index < drumkv1::NUM_ELEMENT_PARAMS)
+			continue;
+		QDomElement eParam = doc.createElement("param");
 		eParam.setAttribute("index", QString::number(i));
 		eParam.setAttribute("name", drumkv1_param::paramName(index));
 		const float fValue = pDrumk->paramValue(index);
@@ -522,7 +539,11 @@ bool drumkv1_param::savePreset (
 		eParams.appendChild(eParam);
 	}
 	ePreset.appendChild(eParams);
-	doc.appendChild(ePreset);
+
+	QDomElement eCurrentElement = doc.createElement("current-element");
+	eCurrentElement.appendChild(doc.createTextNode(
+		QString::number(pDrumk->currentElement())));
+	ePreset.appendChild(eCurrentElement);
 
 	if (pDrumk->isTuningEnabled()) {
 		QDomElement eTuning = doc.createElement("tuning");
@@ -530,6 +551,8 @@ bool drumkv1_param::savePreset (
 		ePreset.appendChild(eTuning);
 	}
 
+	doc.appendChild(ePreset);
+
 	QFile file(fi.filePath());
 	if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate))
 		return false;
