@@ -1,7 +1,7 @@
 // drumkv1_ui.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -192,6 +192,12 @@ void drumkv1_ui::updatePreset ( bool bDirty )
 }
 
 
+void drumkv1_ui::updateParam ( drumkv1::ParamIndex index )
+{
+	m_pDrumk->updateParam(index);
+}
+
+
 void drumkv1_ui::midiInEnabled ( bool bEnabled )
 {
 	m_pDrumk->midiInEnabled(bEnabled);
