@@ -1368,6 +1368,12 @@ void drumkv1widget::refreshElements (void)
 	m_ui.Elements->setCurrentIndex(iCurrentNote);
 	m_ui.Gen1Sample->setSampleName(completeNoteName(iCurrentNote));
 
+	drumkv1widget_keybd *pKeybd = m_ui.StatusBar->keybd();
+	for (int iNote = 0; iNote < m_ui.Elements->model()->rowCount(); ++iNote) {
+		drumkv1_element *element = pDrumkUi->element(iNote);
+		pKeybd->setNoteEnabled(iNote, element && element->sampleFile());
+	}
+
 	m_ui.Elements->blockSignals(bBlockSignals);
 }
 
