@@ -23,6 +23,7 @@
 #define __drumkv1widget_filt_h
 
 #include <QFrame>
+#include <QPainterPath>
 
 
 //----------------------------------------------------------------------------
@@ -41,9 +42,9 @@ public:
 
 	// Parameter getters.
 	float cutoff() const;
-	float reso() const;
-	float type() const;
-	float slope() const;
+	float reso()   const;
+	float type()   const;
+	float slope()  const;
 
 public slots:
 
@@ -64,6 +65,22 @@ protected:
 	// Draw canvas.
 	void paintEvent(QPaintEvent *);
 
+	// Filter types/slopes.
+	enum Types {
+		LPF = 0,
+		BPF = 1,
+		HPF = 2,
+		BRF = 3,
+		L2F = 4
+	};
+
+	enum Slopes {
+		S12DB    = 0,
+		S24DB    = 1,
+		SBIQUAD  = 2,
+		SFORMANT = 3
+	};
+
 	// Drag/move curve.
 	void dragCurve(const QPoint& pos);
 
@@ -73,17 +90,26 @@ protected:
 	void mouseReleaseEvent(QMouseEvent *pMouseEvent);
 	void wheelEvent(QWheelEvent *pWheelEvent);
 
+	// Resize canvas.
+	void resizeEvent(QResizeEvent *);
+
+	// Update the drawing path.
+	void updatePath();
+
 private:
 
 	// Instance state.
 	float m_fCutoff;
 	float m_fReso;
-	float m_fType;
-	float m_fSlope;
+	int   m_iType;
+	int   m_iSlope;
 
 	// Drag state.
 	bool m_bDragging;
 	QPoint m_posDrag;
+
+	// Drawable path.
+	QPainterPath m_path;
 };
 
 #endif	// __drumkv1widget_filt_h
