@@ -611,6 +611,13 @@ void drumkv1widget_sample::openSample ( const QString& sName )
 				sExts += ' ' + sExt;
 				exts.append(sExt);
 			}
+			if (sExtension == "oga") {
+				sExt = sExtMask.arg("ogg");
+				if (!exts.contains(sExt)) {
+					sExts += ' ' + sExt;
+					exts.append(sExt);
+				}
+			}
 			s_filters.append(sFilterMask.arg(sFilterName).arg(sExts));
 		}
 		s_filters.prepend(sFilterMask.arg(tr("Audio files")).arg(exts.join(" ")));
